# PyArchery

![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)
![Servier Inspired](https://raw.githubusercontent.com/servierhub/.github/main/badges/inspired.svg)

This repository is a binging of Archery for Python language.

## Description

In today's data-driven landscape, navigating the complexities of semi-structured documents poses a significant challenge
for organizations. These documents, characterized by diverse formats and a lack of standardization, often require
specialized skills for effective manipulation and analysis. However, we propose a novel framework to address this
challenge. By leveraging innovative algorithms and machine learning techniques, [Archery](https://github.com/RomualdRousseau/Archery)
offers a solution that gives you control over the data extraction process with tweakable and repeatable settings.
Moreover, by automating the extraction process, it not only saves time but also minimizes errors, particularly beneficial
for industries dealing with large volumes of such documents. Crucially, this framework integrates with machine learning workflows,
unlocking new possibilities for data enrichment and predictive modeling. By leveraging determinist algorithms, this framework is perfect
to prepare your data for training processes in a predictive and reproductible manner. Aligned with the paradigm of data as a service,
it offers a scalable and efficient means of managing semi-structured data, thereby expanding the toolkit of data services available
to organizations.

Visit our [full documentation](https://romualdrousseau.github.io/PyArchery/) and learn more about how it works, try our
tutorials and find a full list of plugins and models.

## Getting Started

### Dependencies

- The Java Developer Kit, version 17.
- Python 3.8.2 or above.
- Pip 20.0.2 or above.
- Poetry 1.7.1 or above.
- Just 1.24.0 or above.

### Install and setup locally

Run the following command line:

```bash
pip install pyjarchery
```

### Run the examples

To run the tutorial1:

```bash
python examples/tutorial1.py
```

To run the tutorial2:

```bash
python examples/tutorial2.py
```

### Documentation

The following links will give you documentation about some background information, takes you through some implementation details,
and then focuses on step-by-step instructions for getting the most out of Any2Json:

- Using PyArchery: [here](https://romualdrousseau.github.io/PyArchery/).

## Contribute

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## Authors

- Romuald Rousseau, romuald.rousseau@servier.com

## Version History

- 0.1.6
- 0.1.5
- 0.1.4
- 0.1.1
- 0.1.0
- Initial Release
